# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/lightclients/solomachine/v2/solomachine.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ibc/lightclients/solomachine/v2/solomachine.proto\x12\x1fibc.lightclients.solomachine.v2\x1a\'ibc/core/connection/v1/connection.proto\x1a!ibc/core/channel/v1/channel.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"\xe5\x01\n\x0b\x43lientState\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\x12\x1b\n\tis_frozen\x18\x02 \x01(\x08R\x08isFrozen\x12X\n\x0f\x63onsensus_state\x18\x03 \x01(\x0b\x32/.ibc.lightclients.solomachine.v2.ConsensusStateR\x0e\x63onsensusState\x12=\n\x1b\x61llow_update_after_proposal\x18\x04 \x01(\x08R\x18\x61llowUpdateAfterProposal:\x04\x88\xa0\x1f\x00\"\x8b\x01\n\x0e\x43onsensusState\x12\x33\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\tpublicKey\x12 \n\x0b\x64iversifier\x18\x02 \x01(\tR\x0b\x64iversifier\x12\x1c\n\ttimestamp\x18\x03 \x01(\x04R\ttimestamp:\x04\x88\xa0\x1f\x00\"\xcb\x01\n\x06Header\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\x12\x1c\n\tsignature\x18\x03 \x01(\x0cR\tsignature\x12:\n\x0enew_public_key\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0cnewPublicKey\x12\'\n\x0fnew_diversifier\x18\x05 \x01(\tR\x0enewDiversifier:\x04\x88\xa0\x1f\x00\"\xfd\x01\n\x0cMisbehaviour\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12\x1a\n\x08sequence\x18\x02 \x01(\x04R\x08sequence\x12V\n\rsignature_one\x18\x03 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v2.SignatureAndDataR\x0csignatureOne\x12V\n\rsignature_two\x18\x04 \x01(\x0b\x32\x31.ibc.lightclients.solomachine.v2.SignatureAndDataR\x0csignatureTwo:\x04\x88\xa0\x1f\x00\"\xb0\x01\n\x10SignatureAndData\x12\x1c\n\tsignature\x18\x01 \x01(\x0cR\tsignature\x12\x46\n\tdata_type\x18\x02 \x01(\x0e\x32).ibc.lightclients.solomachine.v2.DataTypeR\x08\x64\x61taType\x12\x12\n\x04\x64\x61ta\x18\x03 \x01(\x0cR\x04\x64\x61ta\x12\x1c\n\ttimestamp\x18\x04 \x01(\x04R\ttimestamp:\x04\x88\xa0\x1f\x00\"e\n\x18TimestampedSignatureData\x12%\n\x0esignature_data\x18\x01 \x01(\x0cR\rsignatureData\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp:\x04\x88\xa0\x1f\x00\"\xc9\x01\n\tSignBytes\x12\x1a\n\x08sequence\x18\x01 \x01(\x04R\x08sequence\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\x12 \n\x0b\x64iversifier\x18\x03 \x01(\tR\x0b\x64iversifier\x12\x46\n\tdata_type\x18\x04 \x01(\x0e\x32).ibc.lightclients.solomachine.v2.DataTypeR\x08\x64\x61taType\x12\x12\n\x04\x64\x61ta\x18\x05 \x01(\x0cR\x04\x64\x61ta:\x04\x88\xa0\x1f\x00\"q\n\nHeaderData\x12\x34\n\x0bnew_pub_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\tnewPubKey\x12\'\n\x0fnew_diversifier\x18\x02 \x01(\tR\x0enewDiversifier:\x04\x88\xa0\x1f\x00\"d\n\x0f\x43lientStateData\x12\x12\n\x04path\x18\x01 \x01(\x0cR\x04path\x12\x37\n\x0c\x63lient_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0b\x63lientState:\x04\x88\xa0\x1f\x00\"m\n\x12\x43onsensusStateData\x12\x12\n\x04path\x18\x01 \x01(\x0cR\x04path\x12=\n\x0f\x63onsensus_state\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0e\x63onsensusState:\x04\x88\xa0\x1f\x00\"v\n\x13\x43onnectionStateData\x12\x12\n\x04path\x18\x01 \x01(\x0cR\x04path\x12\x45\n\nconnection\x18\x02 \x01(\x0b\x32%.ibc.core.connection.v1.ConnectionEndR\nconnection:\x04\x88\xa0\x1f\x00\"d\n\x10\x43hannelStateData\x12\x12\n\x04path\x18\x01 \x01(\x0cR\x04path\x12\x36\n\x07\x63hannel\x18\x02 \x01(\x0b\x32\x1c.ibc.core.channel.v1.ChannelR\x07\x63hannel:\x04\x88\xa0\x1f\x00\"J\n\x14PacketCommitmentData\x12\x12\n\x04path\x18\x01 \x01(\x0cR\x04path\x12\x1e\n\ncommitment\x18\x02 \x01(\x0cR\ncommitment\"Y\n\x19PacketAcknowledgementData\x12\x12\n\x04path\x18\x01 \x01(\x0cR\x04path\x12(\n\x0f\x61\x63knowledgement\x18\x02 \x01(\x0cR\x0f\x61\x63knowledgement\".\n\x18PacketReceiptAbsenceData\x12\x12\n\x04path\x18\x01 \x01(\x0cR\x04path\"N\n\x14NextSequenceRecvData\x12\x12\n\x04path\x18\x01 \x01(\x0cR\x04path\x12\"\n\rnext_seq_recv\x18\x02 \x01(\x04R\x0bnextSeqRecv*\x8c\x04\n\x08\x44\x61taType\x12\x38\n#DATA_TYPE_UNINITIALIZED_UNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12&\n\x16\x44\x41TA_TYPE_CLIENT_STATE\x10\x01\x1a\n\x8a\x9d \x06\x43LIENT\x12,\n\x19\x44\x41TA_TYPE_CONSENSUS_STATE\x10\x02\x1a\r\x8a\x9d \tCONSENSUS\x12.\n\x1a\x44\x41TA_TYPE_CONNECTION_STATE\x10\x03\x1a\x0e\x8a\x9d \nCONNECTION\x12(\n\x17\x44\x41TA_TYPE_CHANNEL_STATE\x10\x04\x1a\x0b\x8a\x9d \x07\x43HANNEL\x12\x35\n\x1b\x44\x41TA_TYPE_PACKET_COMMITMENT\x10\x05\x1a\x14\x8a\x9d \x10PACKETCOMMITMENT\x12?\n DATA_TYPE_PACKET_ACKNOWLEDGEMENT\x10\x06\x1a\x19\x8a\x9d \x15PACKETACKNOWLEDGEMENT\x12>\n DATA_TYPE_PACKET_RECEIPT_ABSENCE\x10\x07\x1a\x18\x8a\x9d \x14PACKETRECEIPTABSENCE\x12\x36\n\x1c\x44\x41TA_TYPE_NEXT_SEQUENCE_RECV\x10\x08\x1a\x14\x8a\x9d \x10NEXTSEQUENCERECV\x12 \n\x10\x44\x41TA_TYPE_HEADER\x10\t\x1a\n\x8a\x9d \x06HEADER\x1a\x04\x88\xa3\x1e\x00\x42\x98\x02\n#com.ibc.lightclients.solomachine.v2B\x10SolomachineProtoP\x01Z@github.com/cosmos/ibc-go/v8/modules/core/02-client/migrations/v7\xa2\x02\x03ILS\xaa\x02\x1fIbc.Lightclients.Solomachine.V2\xca\x02\x1fIbc\\Lightclients\\Solomachine\\V2\xe2\x02+Ibc\\Lightclients\\Solomachine\\V2\\GPBMetadata\xea\x02\"Ibc::Lightclients::Solomachine::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.lightclients.solomachine.v2.solomachine_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.ibc.lightclients.solomachine.v2B\020SolomachineProtoP\001Z@github.com/cosmos/ibc-go/v8/modules/core/02-client/migrations/v7\242\002\003ILS\252\002\037Ibc.Lightclients.Solomachine.V2\312\002\037Ibc\\Lightclients\\Solomachine\\V2\342\002+Ibc\\Lightclients\\Solomachine\\V2\\GPBMetadata\352\002\"Ibc::Lightclients::Solomachine::V2'
  _globals['_DATATYPE']._loaded_options = None
  _globals['_DATATYPE']._serialized_options = b'\210\243\036\000'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_UNINITIALIZED_UNSPECIFIED"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_UNINITIALIZED_UNSPECIFIED"]._serialized_options = b'\212\235 \013UNSPECIFIED'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CLIENT_STATE"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CLIENT_STATE"]._serialized_options = b'\212\235 \006CLIENT'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CONSENSUS_STATE"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CONSENSUS_STATE"]._serialized_options = b'\212\235 \tCONSENSUS'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CONNECTION_STATE"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CONNECTION_STATE"]._serialized_options = b'\212\235 \nCONNECTION'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CHANNEL_STATE"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_CHANNEL_STATE"]._serialized_options = b'\212\235 \007CHANNEL'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_COMMITMENT"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_COMMITMENT"]._serialized_options = b'\212\235 \020PACKETCOMMITMENT'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_ACKNOWLEDGEMENT"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_ACKNOWLEDGEMENT"]._serialized_options = b'\212\235 \025PACKETACKNOWLEDGEMENT'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_RECEIPT_ABSENCE"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_PACKET_RECEIPT_ABSENCE"]._serialized_options = b'\212\235 \024PACKETRECEIPTABSENCE'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_NEXT_SEQUENCE_RECV"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_NEXT_SEQUENCE_RECV"]._serialized_options = b'\212\235 \020NEXTSEQUENCERECV'
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_HEADER"]._loaded_options = None
  _globals['_DATATYPE'].values_by_name["DATA_TYPE_HEADER"]._serialized_options = b'\212\235 \006HEADER'
  _globals['_CLIENTSTATE']._loaded_options = None
  _globals['_CLIENTSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_CONSENSUSSTATE']._loaded_options = None
  _globals['_CONSENSUSSTATE']._serialized_options = b'\210\240\037\000'
  _globals['_HEADER']._loaded_options = None
  _globals['_HEADER']._serialized_options = b'\210\240\037\000'
  _globals['_MISBEHAVIOUR']._loaded_options = None
  _globals['_MISBEHAVIOUR']._serialized_options = b'\210\240\037\000'
  _globals['_SIGNATUREANDDATA']._loaded_options = None
  _globals['_SIGNATUREANDDATA']._serialized_options = b'\210\240\037\000'
  _globals['_TIMESTAMPEDSIGNATUREDATA']._loaded_options = None
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_options = b'\210\240\037\000'
  _globals['_SIGNBYTES']._loaded_options = None
  _globals['_SIGNBYTES']._serialized_options = b'\210\240\037\000'
  _globals['_HEADERDATA']._loaded_options = None
  _globals['_HEADERDATA']._serialized_options = b'\210\240\037\000'
  _globals['_CLIENTSTATEDATA']._loaded_options = None
  _globals['_CLIENTSTATEDATA']._serialized_options = b'\210\240\037\000'
  _globals['_CONSENSUSSTATEDATA']._loaded_options = None
  _globals['_CONSENSUSSTATEDATA']._serialized_options = b'\210\240\037\000'
  _globals['_CONNECTIONSTATEDATA']._loaded_options = None
  _globals['_CONNECTIONSTATEDATA']._serialized_options = b'\210\240\037\000'
  _globals['_CHANNELSTATEDATA']._loaded_options = None
  _globals['_CHANNELSTATEDATA']._serialized_options = b'\210\240\037\000'
  _globals['_DATATYPE']._serialized_start=2379
  _globals['_DATATYPE']._serialized_end=2903
  _globals['_CLIENTSTATE']._serialized_start=212
  _globals['_CLIENTSTATE']._serialized_end=441
  _globals['_CONSENSUSSTATE']._serialized_start=444
  _globals['_CONSENSUSSTATE']._serialized_end=583
  _globals['_HEADER']._serialized_start=586
  _globals['_HEADER']._serialized_end=789
  _globals['_MISBEHAVIOUR']._serialized_start=792
  _globals['_MISBEHAVIOUR']._serialized_end=1045
  _globals['_SIGNATUREANDDATA']._serialized_start=1048
  _globals['_SIGNATUREANDDATA']._serialized_end=1224
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_start=1226
  _globals['_TIMESTAMPEDSIGNATUREDATA']._serialized_end=1327
  _globals['_SIGNBYTES']._serialized_start=1330
  _globals['_SIGNBYTES']._serialized_end=1531
  _globals['_HEADERDATA']._serialized_start=1533
  _globals['_HEADERDATA']._serialized_end=1646
  _globals['_CLIENTSTATEDATA']._serialized_start=1648
  _globals['_CLIENTSTATEDATA']._serialized_end=1748
  _globals['_CONSENSUSSTATEDATA']._serialized_start=1750
  _globals['_CONSENSUSSTATEDATA']._serialized_end=1859
  _globals['_CONNECTIONSTATEDATA']._serialized_start=1861
  _globals['_CONNECTIONSTATEDATA']._serialized_end=1979
  _globals['_CHANNELSTATEDATA']._serialized_start=1981
  _globals['_CHANNELSTATEDATA']._serialized_end=2081
  _globals['_PACKETCOMMITMENTDATA']._serialized_start=2083
  _globals['_PACKETCOMMITMENTDATA']._serialized_end=2157
  _globals['_PACKETACKNOWLEDGEMENTDATA']._serialized_start=2159
  _globals['_PACKETACKNOWLEDGEMENTDATA']._serialized_end=2248
  _globals['_PACKETRECEIPTABSENCEDATA']._serialized_start=2250
  _globals['_PACKETRECEIPTABSENCEDATA']._serialized_end=2296
  _globals['_NEXTSEQUENCERECVDATA']._serialized_start=2298
  _globals['_NEXTSEQUENCERECVDATA']._serialized_end=2376
# @@protoc_insertion_point(module_scope)



import logging
from logging import Logger
from typing import Type

# If the application using the SDK has its own logging configuration, the following basic configuration will have no
# effect
logging.basicConfig(format="%(asctime)s - %(name)s - %(levelname)s - %(message)s")


class LoggerProvider:
    def logger(self) -> Logger:
        return logging.getLogger(__name__)

    def logger_for_class(self, logging_class: Type) -> Logger:
        return logging.getLogger(f"{logging_class.__module__}.{logging_class.__name__}")



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.cometbft.services.version.v1 import version_pb2 as cometbft_dot_services_dot_version_dot_v1_dot_version__pb2


class VersionServiceStub(object):
    """VersionService simply provides version information about the node and the
    protocols it uses.

    The intention with this service is to offer a stable interface through which
    clients can access version information. This means that the version of the
    service should be kept stable at v1, with GetVersionResponse evolving only
    in non-breaking ways.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetVersion = channel.unary_unary(
                '/cometbft.services.version.v1.VersionService/GetVersion',
                request_serializer=cometbft_dot_services_dot_version_dot_v1_dot_version__pb2.GetVersionRequest.SerializeToString,
                response_deserializer=cometbft_dot_services_dot_version_dot_v1_dot_version__pb2.GetVersionResponse.FromString,
                _registered_method=True)


class VersionServiceServicer(object):
    """VersionService simply provides version information about the node and the
    protocols it uses.

    The intention with this service is to offer a stable interface through which
    clients can access version information. This means that the version of the
    service should be kept stable at v1, with GetVersionResponse evolving only
    in non-breaking ways.
    """

    def GetVersion(self, request, context):
        """GetVersion retrieves version information about the node and the protocols
        it implements.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_VersionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVersion,
                    request_deserializer=cometbft_dot_services_dot_version_dot_v1_dot_version__pb2.GetVersionRequest.FromString,
                    response_serializer=cometbft_dot_services_dot_version_dot_v1_dot_version__pb2.GetVersionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cometbft.services.version.v1.VersionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cometbft.services.version.v1.VersionService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class VersionService(object):
    """VersionService simply provides version information about the node and the
    protocols it uses.

    The intention with this service is to offer a stable interface through which
    clients can access version information. This means that the version of the
    service should be kept stable at v1, with GetVersionResponse evolving only
    in non-breaking ways.
    """

    @staticmethod
    def GetVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cometbft.services.version.v1.VersionService/GetVersion',
            cometbft_dot_services_dot_version_dot_v1_dot_version__pb2.GetVersionRequest.SerializeToString,
            cometbft_dot_services_dot_version_dot_v1_dot_version__pb2.GetVersionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/channel/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ibc/core/channel/v1/genesis.proto\x12\x13ibc.core.channel.v1\x1a\x14gogoproto/gogo.proto\x1a!ibc/core/channel/v1/channel.proto\"\xb2\x05\n\x0cGenesisState\x12]\n\x08\x63hannels\x18\x01 \x03(\x0b\x32&.ibc.core.channel.v1.IdentifiedChannelB\x19\xc8\xde\x1f\x00\xfa\xde\x1f\x11IdentifiedChannelR\x08\x63hannels\x12R\n\x10\x61\x63knowledgements\x18\x02 \x03(\x0b\x32 .ibc.core.channel.v1.PacketStateB\x04\xc8\xde\x1f\x00R\x10\x61\x63knowledgements\x12H\n\x0b\x63ommitments\x18\x03 \x03(\x0b\x32 .ibc.core.channel.v1.PacketStateB\x04\xc8\xde\x1f\x00R\x0b\x63ommitments\x12\x42\n\x08receipts\x18\x04 \x03(\x0b\x32 .ibc.core.channel.v1.PacketStateB\x04\xc8\xde\x1f\x00R\x08receipts\x12P\n\x0esend_sequences\x18\x05 \x03(\x0b\x32#.ibc.core.channel.v1.PacketSequenceB\x04\xc8\xde\x1f\x00R\rsendSequences\x12P\n\x0erecv_sequences\x18\x06 \x03(\x0b\x32#.ibc.core.channel.v1.PacketSequenceB\x04\xc8\xde\x1f\x00R\rrecvSequences\x12N\n\rack_sequences\x18\x07 \x03(\x0b\x32#.ibc.core.channel.v1.PacketSequenceB\x04\xc8\xde\x1f\x00R\x0c\x61\x63kSequences\x12\x32\n\x15next_channel_sequence\x18\x08 \x01(\x04R\x13nextChannelSequence\x12\x39\n\x06params\x18\t \x01(\x0b\x32\x1b.ibc.core.channel.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"d\n\x0ePacketSequence\x12\x17\n\x07port_id\x18\x01 \x01(\tR\x06portId\x12\x1d\n\nchannel_id\x18\x02 \x01(\tR\tchannelId\x12\x1a\n\x08sequence\x18\x03 \x01(\x04R\x08sequenceB\xd1\x01\n\x17\x63om.ibc.core.channel.v1B\x0cGenesisProtoP\x01Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\xa2\x02\x03ICC\xaa\x02\x13Ibc.Core.Channel.V1\xca\x02\x13Ibc\\Core\\Channel\\V1\xe2\x02\x1fIbc\\Core\\Channel\\V1\\GPBMetadata\xea\x02\x16Ibc::Core::Channel::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.channel.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.ibc.core.channel.v1B\014GenesisProtoP\001Z9github.com/cosmos/ibc-go/v8/modules/core/04-channel/types\242\002\003ICC\252\002\023Ibc.Core.Channel.V1\312\002\023Ibc\\Core\\Channel\\V1\342\002\037Ibc\\Core\\Channel\\V1\\GPBMetadata\352\002\026Ibc::Core::Channel::V1'
  _globals['_GENESISSTATE'].fields_by_name['channels']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['channels']._serialized_options = b'\310\336\037\000\372\336\037\021IdentifiedChannel'
  _globals['_GENESISSTATE'].fields_by_name['acknowledgements']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['acknowledgements']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['commitments']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['commitments']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['receipts']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['receipts']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['send_sequences']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['send_sequences']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['recv_sequences']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['recv_sequences']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['ack_sequences']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['ack_sequences']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=116
  _globals['_GENESISSTATE']._serialized_end=806
  _globals['_PACKETSEQUENCE']._serialized_start=808
  _globals['_PACKETSEQUENCE']._serialized_end=908
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.wasmx.v1 import wasmx_pb2 as injective_dot_wasmx_dot_v1_dot_wasmx__pb2
from pyinjective.proto.injective.wasmx.v1 import proposal_pb2 as injective_dot_wasmx_dot_v1_dot_proposal__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1finjective/wasmx/v1/events.proto\x12\x12injective.wasmx.v1\x1a\x1einjective/wasmx/v1/wasmx.proto\x1a!injective/wasmx/v1/proposal.proto\x1a\x14gogoproto/gogo.proto\"\xa9\x01\n\x16\x45ventContractExecution\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12\x1a\n\x08response\x18\x02 \x01(\x0cR\x08response\x12\x1f\n\x0bother_error\x18\x03 \x01(\tR\notherError\x12\'\n\x0f\x65xecution_error\x18\x04 \x01(\tR\x0e\x65xecutionError\"\xee\x02\n\x17\x45ventContractRegistered\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12\x1b\n\tgas_price\x18\x03 \x01(\x04R\x08gasPrice\x12.\n\x13should_pin_contract\x18\x04 \x01(\x08R\x11shouldPinContract\x12\x30\n\x14is_migration_allowed\x18\x05 \x01(\x08R\x12isMigrationAllowed\x12\x17\n\x07\x63ode_id\x18\x06 \x01(\x04R\x06\x63odeId\x12#\n\radmin_address\x18\x07 \x01(\tR\x0c\x61\x64minAddress\x12\'\n\x0fgranter_address\x18\x08 \x01(\tR\x0egranterAddress\x12\x42\n\x0c\x66unding_mode\x18\t \x01(\x0e\x32\x1f.injective.wasmx.v1.FundingModeR\x0b\x66undingMode\"F\n\x19\x45ventContractDeregistered\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddressB\xdc\x01\n\x16\x63om.injective.wasmx.v1B\x0b\x45ventsProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\xa2\x02\x03IWX\xaa\x02\x12Injective.Wasmx.V1\xca\x02\x12Injective\\Wasmx\\V1\xe2\x02\x1eInjective\\Wasmx\\V1\\GPBMetadata\xea\x02\x14Injective::Wasmx::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.wasmx.v1B\013EventsProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types\242\002\003IWX\252\002\022Injective.Wasmx.V1\312\002\022Injective\\Wasmx\\V1\342\002\036Injective\\Wasmx\\V1\\GPBMetadata\352\002\024Injective::Wasmx::V1'
  _globals['_EVENTCONTRACTEXECUTION']._serialized_start=145
  _globals['_EVENTCONTRACTEXECUTION']._serialized_end=314
  _globals['_EVENTCONTRACTREGISTERED']._serialized_start=317
  _globals['_EVENTCONTRACTREGISTERED']._serialized_end=683
  _globals['_EVENTCONTRACTDEREGISTERED']._serialized_start=685
  _globals['_EVENTCONTRACTDEREGISTERED']._serialized_end=755
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import injective_referral_rpc_pb2 as exchange_dot_injective__referral__rpc__pb2


class InjectiveReferralRPCStub(object):
    """InjectiveReferralRPC defines gRPC API for referral system
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetReferrerDetails = channel.unary_unary(
                '/injective_referral_rpc.InjectiveReferralRPC/GetReferrerDetails',
                request_serializer=exchange_dot_injective__referral__rpc__pb2.GetReferrerDetailsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__referral__rpc__pb2.GetReferrerDetailsResponse.FromString,
                _registered_method=True)
        self.GetInviteeDetails = channel.unary_unary(
                '/injective_referral_rpc.InjectiveReferralRPC/GetInviteeDetails',
                request_serializer=exchange_dot_injective__referral__rpc__pb2.GetInviteeDetailsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__referral__rpc__pb2.GetInviteeDetailsResponse.FromString,
                _registered_method=True)
        self.GetReferrerByCode = channel.unary_unary(
                '/injective_referral_rpc.InjectiveReferralRPC/GetReferrerByCode',
                request_serializer=exchange_dot_injective__referral__rpc__pb2.GetReferrerByCodeRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__referral__rpc__pb2.GetReferrerByCodeResponse.FromString,
                _registered_method=True)


class InjectiveReferralRPCServicer(object):
    """InjectiveReferralRPC defines gRPC API for referral system
    """

    def GetReferrerDetails(self, request, context):
        """Get referrer details including their invitees, commissions and trading
        volumes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetInviteeDetails(self, request, context):
        """Get invitee details including their referrer, trading volume and join date
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReferrerByCode(self, request, context):
        """Get referrer details by their referral code
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveReferralRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetReferrerDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReferrerDetails,
                    request_deserializer=exchange_dot_injective__referral__rpc__pb2.GetReferrerDetailsRequest.FromString,
                    response_serializer=exchange_dot_injective__referral__rpc__pb2.GetReferrerDetailsResponse.SerializeToString,
            ),
            'GetInviteeDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.GetInviteeDetails,
                    request_deserializer=exchange_dot_injective__referral__rpc__pb2.GetInviteeDetailsRequest.FromString,
                    response_serializer=exchange_dot_injective__referral__rpc__pb2.GetInviteeDetailsResponse.SerializeToString,
            ),
            'GetReferrerByCode': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReferrerByCode,
                    request_deserializer=exchange_dot_injective__referral__rpc__pb2.GetReferrerByCodeRequest.FromString,
                    response_serializer=exchange_dot_injective__referral__rpc__pb2.GetReferrerByCodeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_referral_rpc.InjectiveReferralRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective_referral_rpc.InjectiveReferralRPC', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InjectiveReferralRPC(object):
    """InjectiveReferralRPC defines gRPC API for referral system
    """

    @staticmethod
    def GetReferrerDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_referral_rpc.InjectiveReferralRPC/GetReferrerDetails',
            exchange_dot_injective__referral__rpc__pb2.GetReferrerDetailsRequest.SerializeToString,
            exchange_dot_injective__referral__rpc__pb2.GetReferrerDetailsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetInviteeDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_referral_rpc.InjectiveReferralRPC/GetInviteeDetails',
            exchange_dot_injective__referral__rpc__pb2.GetInviteeDetailsRequest.SerializeToString,
            exchange_dot_injective__referral__rpc__pb2.GetInviteeDetailsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetReferrerByCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_referral_rpc.InjectiveReferralRPC/GetReferrerByCode',
            exchange_dot_injective__referral__rpc__pb2.GetReferrerByCodeRequest.SerializeToString,
            exchange_dot_injective__referral__rpc__pb2.GetReferrerByCodeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/access_tuple.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/evm/v1/access_tuple.proto\x12\x10injective.evm.v1\x1a\x14gogoproto/gogo.proto\"a\n\x0b\x41\x63\x63\x65ssTuple\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x32\n\x0cstorage_keys\x18\x02 \x03(\tB\x0f\xea\xde\x1f\x0bstorageKeysR\x0bstorageKeys:\x04\x88\xa0\x1f\x00\x42\xd5\x01\n\x14\x63om.injective.evm.v1B\x10\x41\x63\x63\x65ssTupleProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.access_tuple_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\020AccessTupleProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_ACCESSTUPLE'].fields_by_name['storage_keys']._loaded_options = None
  _globals['_ACCESSTUPLE'].fields_by_name['storage_keys']._serialized_options = b'\352\336\037\013storageKeys'
  _globals['_ACCESSTUPLE']._loaded_options = None
  _globals['_ACCESSTUPLE']._serialized_options = b'\210\240\037\000'
  _globals['_ACCESSTUPLE']._serialized_start=79
  _globals['_ACCESSTUPLE']._serialized_end=176
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/consensus/v1beta1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cometbft.types.v1beta1 import types_pb2 as cometbft_dot_types_dot_v1beta1_dot_types__pb2
from pyinjective.proto.cometbft.libs.bits.v1 import types_pb2 as cometbft_dot_libs_dot_bits_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&cometbft/consensus/v1beta1/types.proto\x12\x1a\x63ometbft.consensus.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\"cometbft/types/v1beta1/types.proto\x1a!cometbft/libs/bits/v1/types.proto\"\xb5\x01\n\x0cNewRoundStep\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12\x12\n\x04step\x18\x03 \x01(\rR\x04step\x12\x37\n\x18seconds_since_start_time\x18\x04 \x01(\x03R\x15secondsSinceStartTime\x12*\n\x11last_commit_round\x18\x05 \x01(\x05R\x0flastCommitRound\"\xfc\x01\n\rNewValidBlock\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12^\n\x15\x62lock_part_set_header\x18\x03 \x01(\x0b\x32%.cometbft.types.v1beta1.PartSetHeaderB\x04\xc8\xde\x1f\x00R\x12\x62lockPartSetHeader\x12@\n\x0b\x62lock_parts\x18\x04 \x01(\x0b\x32\x1f.cometbft.libs.bits.v1.BitArrayR\nblockParts\x12\x1b\n\tis_commit\x18\x05 \x01(\x08R\x08isCommit\"N\n\x08Proposal\x12\x42\n\x08proposal\x18\x01 \x01(\x0b\x32 .cometbft.types.v1beta1.ProposalB\x04\xc8\xde\x1f\x00R\x08proposal\"\x9d\x01\n\x0bProposalPOL\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12,\n\x12proposal_pol_round\x18\x02 \x01(\x05R\x10proposalPolRound\x12H\n\x0cproposal_pol\x18\x03 \x01(\x0b\x32\x1f.cometbft.libs.bits.v1.BitArrayB\x04\xc8\xde\x1f\x00R\x0bproposalPol\"q\n\tBlockPart\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12\x36\n\x04part\x18\x03 \x01(\x0b\x32\x1c.cometbft.types.v1beta1.PartB\x04\xc8\xde\x1f\x00R\x04part\"8\n\x04Vote\x12\x30\n\x04vote\x18\x01 \x01(\x0b\x32\x1c.cometbft.types.v1beta1.VoteR\x04vote\"\x88\x01\n\x07HasVote\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32%.cometbft.types.v1beta1.SignedMsgTypeR\x04type\x12\x14\n\x05index\x18\x04 \x01(\x05R\x05index\"\xc4\x01\n\x0cVoteSetMaj23\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32%.cometbft.types.v1beta1.SignedMsgTypeR\x04type\x12K\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x1f.cometbft.types.v1beta1.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockIDR\x07\x62lockId\"\x80\x02\n\x0bVoteSetBits\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12\x14\n\x05round\x18\x02 \x01(\x05R\x05round\x12\x39\n\x04type\x18\x03 \x01(\x0e\x32%.cometbft.types.v1beta1.SignedMsgTypeR\x04type\x12K\n\x08\x62lock_id\x18\x04 \x01(\x0b\x32\x1f.cometbft.types.v1beta1.BlockIDB\x0f\xc8\xde\x1f\x00\xe2\xde\x1f\x07\x42lockIDR\x07\x62lockId\x12;\n\x05votes\x18\x05 \x01(\x0b\x32\x1f.cometbft.libs.bits.v1.BitArrayB\x04\xc8\xde\x1f\x00R\x05votes\"\xac\x05\n\x07Message\x12P\n\x0enew_round_step\x18\x01 \x01(\x0b\x32(.cometbft.consensus.v1beta1.NewRoundStepH\x00R\x0cnewRoundStep\x12S\n\x0fnew_valid_block\x18\x02 \x01(\x0b\x32).cometbft.consensus.v1beta1.NewValidBlockH\x00R\rnewValidBlock\x12\x42\n\x08proposal\x18\x03 \x01(\x0b\x32$.cometbft.consensus.v1beta1.ProposalH\x00R\x08proposal\x12L\n\x0cproposal_pol\x18\x04 \x01(\x0b\x32\'.cometbft.consensus.v1beta1.ProposalPOLH\x00R\x0bproposalPol\x12\x46\n\nblock_part\x18\x05 \x01(\x0b\x32%.cometbft.consensus.v1beta1.BlockPartH\x00R\tblockPart\x12\x36\n\x04vote\x18\x06 \x01(\x0b\x32 .cometbft.consensus.v1beta1.VoteH\x00R\x04vote\x12@\n\x08has_vote\x18\x07 \x01(\x0b\x32#.cometbft.consensus.v1beta1.HasVoteH\x00R\x07hasVote\x12P\n\x0evote_set_maj23\x18\x08 \x01(\x0b\x32(.cometbft.consensus.v1beta1.VoteSetMaj23H\x00R\x0cvoteSetMaj23\x12M\n\rvote_set_bits\x18\t \x01(\x0b\x32\'.cometbft.consensus.v1beta1.VoteSetBitsH\x00R\x0bvoteSetBitsB\x05\n\x03sumB\xf3\x01\n\x1e\x63om.cometbft.consensus.v1beta1B\nTypesProtoP\x01Z;github.com/cometbft/cometbft/api/cometbft/consensus/v1beta1\xa2\x02\x03\x43\x43X\xaa\x02\x1a\x43ometbft.Consensus.V1beta1\xca\x02\x1a\x43ometbft\\Consensus\\V1beta1\xe2\x02&Cometbft\\Consensus\\V1beta1\\GPBMetadata\xea\x02\x1c\x43ometbft::Consensus::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.consensus.v1beta1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.cometbft.consensus.v1beta1B\nTypesProtoP\001Z;github.com/cometbft/cometbft/api/cometbft/consensus/v1beta1\242\002\003CCX\252\002\032Cometbft.Consensus.V1beta1\312\002\032Cometbft\\Consensus\\V1beta1\342\002&Cometbft\\Consensus\\V1beta1\\GPBMetadata\352\002\034Cometbft::Consensus::V1beta1'
  _globals['_NEWVALIDBLOCK'].fields_by_name['block_part_set_header']._loaded_options = None
  _globals['_NEWVALIDBLOCK'].fields_by_name['block_part_set_header']._serialized_options = b'\310\336\037\000'
  _globals['_PROPOSAL'].fields_by_name['proposal']._loaded_options = None
  _globals['_PROPOSAL'].fields_by_name['proposal']._serialized_options = b'\310\336\037\000'
  _globals['_PROPOSALPOL'].fields_by_name['proposal_pol']._loaded_options = None
  _globals['_PROPOSALPOL'].fields_by_name['proposal_pol']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKPART'].fields_by_name['part']._loaded_options = None
  _globals['_BLOCKPART'].fields_by_name['part']._serialized_options = b'\310\336\037\000'
  _globals['_VOTESETMAJ23'].fields_by_name['block_id']._loaded_options = None
  _globals['_VOTESETMAJ23'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_VOTESETBITS'].fields_by_name['block_id']._loaded_options = None
  _globals['_VOTESETBITS'].fields_by_name['block_id']._serialized_options = b'\310\336\037\000\342\336\037\007BlockID'
  _globals['_VOTESETBITS'].fields_by_name['votes']._loaded_options = None
  _globals['_VOTESETBITS'].fields_by_name['votes']._serialized_options = b'\310\336\037\000'
  _globals['_NEWROUNDSTEP']._serialized_start=164
  _globals['_NEWROUNDSTEP']._serialized_end=345
  _globals['_NEWVALIDBLOCK']._serialized_start=348
  _globals['_NEWVALIDBLOCK']._serialized_end=600
  _globals['_PROPOSAL']._serialized_start=602
  _globals['_PROPOSAL']._serialized_end=680
  _globals['_PROPOSALPOL']._serialized_start=683
  _globals['_PROPOSALPOL']._serialized_end=840
  _globals['_BLOCKPART']._serialized_start=842
  _globals['_BLOCKPART']._serialized_end=955
  _globals['_VOTE']._serialized_start=957
  _globals['_VOTE']._serialized_end=1013
  _globals['_HASVOTE']._serialized_start=1016
  _globals['_HASVOTE']._serialized_end=1152
  _globals['_VOTESETMAJ23']._serialized_start=1155
  _globals['_VOTESETMAJ23']._serialized_end=1351
  _globals['_VOTESETBITS']._serialized_start=1354
  _globals['_VOTESETBITS']._serialized_end=1610
  _globals['_MESSAGE']._serialized_start=1613
  _globals['_MESSAGE']._serialized_end=2297
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/circuit/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.cosmos.circuit.v1 import types_pb2 as cosmos_dot_circuit_dot_v1_dot_types__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63osmos/circuit/v1/query.proto\x12\x11\x63osmos.circuit.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1d\x63osmos/circuit/v1/types.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1b\x63osmos/query/v1/query.proto\"/\n\x13QueryAccountRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"Q\n\x0f\x41\x63\x63ountResponse\x12>\n\npermission\x18\x01 \x01(\x0b\x32\x1e.cosmos.circuit.v1.PermissionsR\npermission\"^\n\x14QueryAccountsRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xa5\x01\n\x10\x41\x63\x63ountsResponse\x12H\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32,.cosmos.circuit.v1.GenesisAccountPermissionsR\x08\x61\x63\x63ounts\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x1a\n\x18QueryDisabledListRequest\";\n\x14\x44isabledListResponse\x12#\n\rdisabled_list\x18\x01 \x03(\tR\x0c\x64isabledList2\xad\x03\n\x05Query\x12\x89\x01\n\x07\x41\x63\x63ount\x12&.cosmos.circuit.v1.QueryAccountRequest\x1a\".cosmos.circuit.v1.AccountResponse\"2\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\'\x12%/cosmos/circuit/v1/accounts/{address}\x12\x82\x01\n\x08\x41\x63\x63ounts\x12\'.cosmos.circuit.v1.QueryAccountsRequest\x1a#.cosmos.circuit.v1.AccountsResponse\"(\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1d\x12\x1b/cosmos/circuit/v1/accounts\x12\x92\x01\n\x0c\x44isabledList\x12+.cosmos.circuit.v1.QueryDisabledListRequest\x1a\'.cosmos.circuit.v1.DisabledListResponse\",\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02!\x12\x1f/cosmos/circuit/v1/disable_listB\xa7\x01\n\x15\x63om.cosmos.circuit.v1B\nQueryProtoP\x01Z\x1c\x63osmossdk.io/x/circuit/types\xa2\x02\x03\x43\x43X\xaa\x02\x11\x43osmos.Circuit.V1\xca\x02\x11\x43osmos\\Circuit\\V1\xe2\x02\x1d\x43osmos\\Circuit\\V1\\GPBMetadata\xea\x02\x13\x43osmos::Circuit::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.circuit.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.cosmos.circuit.v1B\nQueryProtoP\001Z\034cosmossdk.io/x/circuit/types\242\002\003CCX\252\002\021Cosmos.Circuit.V1\312\002\021Cosmos\\Circuit\\V1\342\002\035Cosmos\\Circuit\\V1\\GPBMetadata\352\002\023Cosmos::Circuit::V1'
  _globals['_QUERY'].methods_by_name['Account']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Account']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\'\022%/cosmos/circuit/v1/accounts/{address}'
  _globals['_QUERY'].methods_by_name['Accounts']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Accounts']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\035\022\033/cosmos/circuit/v1/accounts'
  _globals['_QUERY'].methods_by_name['DisabledList']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DisabledList']._serialized_options = b'\210\347\260*\001\202\323\344\223\002!\022\037/cosmos/circuit/v1/disable_list'
  _globals['_QUERYACCOUNTREQUEST']._serialized_start=186
  _globals['_QUERYACCOUNTREQUEST']._serialized_end=233
  _globals['_ACCOUNTRESPONSE']._serialized_start=235
  _globals['_ACCOUNTRESPONSE']._serialized_end=316
  _globals['_QUERYACCOUNTSREQUEST']._serialized_start=318
  _globals['_QUERYACCOUNTSREQUEST']._serialized_end=412
  _globals['_ACCOUNTSRESPONSE']._serialized_start=415
  _globals['_ACCOUNTSRESPONSE']._serialized_end=580
  _globals['_QUERYDISABLEDLISTREQUEST']._serialized_start=582
  _globals['_QUERYDISABLEDLISTREQUEST']._serialized_end=608
  _globals['_DISABLEDLISTRESPONSE']._serialized_start=610
  _globals['_DISABLEDLISTRESPONSE']._serialized_end=669
  _globals['_QUERY']._serialized_start=672
  _globals['_QUERY']._serialized_end=1101
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.ocr.v1beta1 import query_pb2 as injective_dot_ocr_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service for OCR module.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/injective.ocr.v1beta1.Query/Params',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.FeedConfig = channel.unary_unary(
                '/injective.ocr.v1beta1.Query/FeedConfig',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigRequest.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigResponse.FromString,
                _registered_method=True)
        self.FeedConfigInfo = channel.unary_unary(
                '/injective.ocr.v1beta1.Query/FeedConfigInfo',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigInfoRequest.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigInfoResponse.FromString,
                _registered_method=True)
        self.LatestRound = channel.unary_unary(
                '/injective.ocr.v1beta1.Query/LatestRound',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestRoundRequest.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestRoundResponse.FromString,
                _registered_method=True)
        self.LatestTransmissionDetails = channel.unary_unary(
                '/injective.ocr.v1beta1.Query/LatestTransmissionDetails',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestTransmissionDetailsRequest.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestTransmissionDetailsResponse.FromString,
                _registered_method=True)
        self.OwedAmount = channel.unary_unary(
                '/injective.ocr.v1beta1.Query/OwedAmount',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryOwedAmountRequest.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryOwedAmountResponse.FromString,
                _registered_method=True)
        self.OcrModuleState = channel.unary_unary(
                '/injective.ocr.v1beta1.Query/OcrModuleState',
                request_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
                response_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service for OCR module.
    """

    def Params(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeedConfig(self, request, context):
        """Retrieves the OCR FeedConfig for a given FeedId
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FeedConfigInfo(self, request, context):
        """Retrieves the OCR FeedConfigInfo for a given FeedId
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LatestRound(self, request, context):
        """Retrieves latest round ID and data, including median answer for that round
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LatestTransmissionDetails(self, request, context):
        """LatestTransmissionDetails returns details about the latest trasmission
        recorded on chain for the given feed ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OwedAmount(self, request, context):
        """Retrieves transmitter's owed amount
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def OcrModuleState(self, request, context):
        """Retrieves the entire OCR module's state
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'FeedConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.FeedConfig,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigRequest.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigResponse.SerializeToString,
            ),
            'FeedConfigInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.FeedConfigInfo,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigInfoRequest.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigInfoResponse.SerializeToString,
            ),
            'LatestRound': grpc.unary_unary_rpc_method_handler(
                    servicer.LatestRound,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestRoundRequest.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestRoundResponse.SerializeToString,
            ),
            'LatestTransmissionDetails': grpc.unary_unary_rpc_method_handler(
                    servicer.LatestTransmissionDetails,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestTransmissionDetailsRequest.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestTransmissionDetailsResponse.SerializeToString,
            ),
            'OwedAmount': grpc.unary_unary_rpc_method_handler(
                    servicer.OwedAmount,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryOwedAmountRequest.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryOwedAmountResponse.SerializeToString,
            ),
            'OcrModuleState': grpc.unary_unary_rpc_method_handler(
                    servicer.OcrModuleState,
                    request_deserializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.FromString,
                    response_serializer=injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.ocr.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.ocr.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service for OCR module.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.ocr.v1beta1.Query/Params',
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FeedConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.ocr.v1beta1.Query/FeedConfig',
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigRequest.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FeedConfigInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.ocr.v1beta1.Query/FeedConfigInfo',
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigInfoRequest.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryFeedConfigInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LatestRound(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.ocr.v1beta1.Query/LatestRound',
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestRoundRequest.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestRoundResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LatestTransmissionDetails(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.ocr.v1beta1.Query/LatestTransmissionDetails',
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestTransmissionDetailsRequest.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryLatestTransmissionDetailsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OwedAmount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.ocr.v1beta1.Query/OwedAmount',
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryOwedAmountRequest.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryOwedAmountResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def OcrModuleState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.ocr.v1beta1.Query/OcrModuleState',
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryModuleStateRequest.SerializeToString,
            injective_dot_ocr_dot_v1beta1_dot_query__pb2.QueryModuleStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/services/block/v1/block_service.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cometbft.services.block.v1 import block_pb2 as cometbft_dot_services_dot_block_dot_v1_dot_block__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.cometbft/services/block/v1/block_service.proto\x12\x1a\x63ometbft.services.block.v1\x1a&cometbft/services/block/v1/block.proto2\xfc\x01\n\x0c\x42lockService\x12n\n\x0bGetByHeight\x12..cometbft.services.block.v1.GetByHeightRequest\x1a/.cometbft.services.block.v1.GetByHeightResponse\x12|\n\x0fGetLatestHeight\x12\x32.cometbft.services.block.v1.GetLatestHeightRequest\x1a\x33.cometbft.services.block.v1.GetLatestHeightResponse0\x01\x42\xfb\x01\n\x1e\x63om.cometbft.services.block.v1B\x11\x42lockServiceProtoP\x01Z;github.com/cometbft/cometbft/api/cometbft/services/block/v1\xa2\x02\x03\x43SB\xaa\x02\x1a\x43ometbft.Services.Block.V1\xca\x02\x1a\x43ometbft\\Services\\Block\\V1\xe2\x02&Cometbft\\Services\\Block\\V1\\GPBMetadata\xea\x02\x1d\x43ometbft::Services::Block::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.services.block.v1.block_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036com.cometbft.services.block.v1B\021BlockServiceProtoP\001Z;github.com/cometbft/cometbft/api/cometbft/services/block/v1\242\002\003CSB\252\002\032Cometbft.Services.Block.V1\312\002\032Cometbft\\Services\\Block\\V1\342\002&Cometbft\\Services\\Block\\V1\\GPBMetadata\352\002\035Cometbft::Services::Block::V1'
  _globals['_BLOCKSERVICE']._serialized_start=119
  _globals['_BLOCKSERVICE']._serialized_end=371
# @@protoc_insertion_point(module_scope)
